/*********************************************************************/
/*                   Solomon Systech Limited                         */
/*********************************************************************/
/* Program Name :main.c
/* Description : Define main routines for programming Zilog Z8 Encore! eZ8F642c
/*               8-bit MCU to drive SSD1926 DVK board
/*				 This souce code provides a reference design for customers who intend
/*				 to use any 8-bit MCU to control SSD1926 DVK board
/*				 
/* Author : Aik Hong (SSL Singapore FAE)
/*********************************************************************/

/*********************************************************************/
/*                        Change Log                                 */
/*********************************************************************/
/* 13 March 2008: Initial Revision
/* Modifications :
/* 1.0 : Version 1 
/*********************************************************************/

#include "Header_file.h"
//#include "ssd192X.h"
//#include "lcd.h"
//#include "memory.h"
#include "io.h"
#include "sdcmd.h"
//#include "testjpeg.h"
//#include "serial_flash.h"

void mcu_init_GPIO_lcd(void);
void reset(void);
void Test_read(void);
void Display_Flash(unsigned char sector, unsigned char pageAddress, unsigned char lowAddress);
void Display_SD(void);

extern SD_Test(void);

UINT32 LCD_Offset;	// make LCD_Offset global so that SD portion can access it

void delay_us(int n) /* wait n seconds*/
{
	unsigned long i;
	unsigned long j;
	for (i=0;i<30;i++)
	{
		for (j=0;j<n*1;j++) 
		{ 
			;
		}
	}
}
void mcu_init_GPIO_lcd(void)
{
  /* Port B as output to data lines of LCD */
  PBADDR 	= 0x01;     /* PB Data Dir */
  PBCTL 	= 0x00;    	/* PB Data Dir = output */
  PBADDR 	= 0x03;     /* PB Output Ctrl */
  PBCTL 	= 0x00;    	/* PB Out Ctrl = push-pull */

  PBOUT		= 0x00;     /* Init to 0 first */
 

/*  Port E as output to control lines of LCD */
/* 	PE0 - /RES
 *	PE1 - E
 *	PE2 - RW
 *	PE3 - D/C
 *	PE7 - /CS  */

  PEADDR 	= 0x01;     /* PE Data Dir */
  PECTL 	= 0x00;    	/* PE Data Dir = output */
  PEADDR 	= 0x03;     /* PE Output Ctrl */
  PECTL 	= 0x00;    	/* PE Out Ctrl = push-pull */

  PEOUT		= 0x00;     /* Init to 0 first */

}

void reset(void)
{
	SET_RES_BIT;

	CLEAR_RES_BIT;
	delay_us(10); /* important delay needed */

	SET_RES_BIT;

}

void Set_Clock(void)
{
	// PLL setting for 4MHZ
	SSD_REGWB(0x126, 0x0A);
	SSD_REGWB(0x127, 0xC8);
	SSD_REGWB(0x04,  0x00);
	SSD_REGWB(0x12b, 0xAE);
	SSD_REGWB(0x126, 0x8A);
}


int main(void)
{
	unsigned char dummy;

	UINT8 state = 0;	// to know the status of various test	
	UINT8 pic = 4;		// number of picture to show
	UINT8 buff[512];

	mcu_init_GPIO_lcd();   // setting for the pins to control 1926
	SET_CS_BIT;		
	CLEAR_RW_BIT;
	SET_E_BIT;

	reset();
	Set_Clock();	
	
	state = SD_Test();
	if( state != 0)
	{
		goto end;	// don't need to read if have error
	}
	SD_read(0,buff,1);		// 1st parameter = address of SD card
							// 2nd parameter = point to the buffer
							// 3rd parameter = number of 512 bytes to read
							// once excuted successfully, the values will be in the array buff

end:
	return 0;
}
